Challenge

Struct Challenge 

pub struct Challenge<A> { /* private fields */ }
A DNS, HTTP, or TLS-ALPN challenge as obtained from the Auth.

Implementations

Source

impl Challenge<Http>

pub fn http_token(&self) -> &str

The token is a unique identifier of the challenge. It is the file name in the http challenge like so:

http://<domain-to-be-proven>/.well-known/acme-challenge/<token>
pub fn http_proof(&self) -> Result<String>

The proof is some text content that is placed in the file named by token.

Source

impl Challenge<Dns>

pub fn dns_proof(&self) -> Result<String>

The proof is the TXT record placed under:

_acme-challenge.<domain-to-be-proven>.  TXT  <proof>
Source

impl Challenge<TlsAlpn>

pub fn tls_alpn_proof(&self) -> Result<[u8; 32]>

The proof is the contents of the ACME extension to be placed in the certificate used for validation.

Source

impl<A> Challenge<A>

pub fn need_validate(&self) -> bool

Check whether this challenge really need validation. It might already been done in a previous order for the same account.

pub async fn validate(&self, delay: Duration) -> Result<()>

Tell the ACME API to attempt validating the proof of this challenge.

The user must first update the DNS record or HTTP web server depending on the type challenge being validated.

pub fn api_challenge(&self) -> &ApiChallenge

Access the underlying JSON object for debugging.