pub struct Challenge<A> { /* private fields */ }Expand description
A DNS, HTTP, or TLS-ALPN challenge as obtained from the Auth.
Implementations
Sourceimpl Challenge<Http>
impl Challenge<Http>
Sourcepub fn http_token(&self) -> &str
pub fn http_token(&self) -> &str
The token is a unique identifier of the challenge. It is the file name in the
http challenge like so:
http://<domain-to-be-proven>/.well-known/acme-challenge/<token>Sourcepub fn http_proof(&self) -> Result<String>
pub fn http_proof(&self) -> Result<String>
The proof is some text content that is placed in the file named by token.
Sourceimpl Challenge<TlsAlpn>
impl Challenge<TlsAlpn>
Sourcepub fn tls_alpn_proof(&self) -> Result<[u8; 32]>
pub fn tls_alpn_proof(&self) -> Result<[u8; 32]>
The proof is the contents of the ACME extension to be placed in the
certificate used for validation.
Sourceimpl<A> Challenge<A>
impl<A> Challenge<A>
Sourcepub fn need_validate(&self) -> bool
pub fn need_validate(&self) -> bool
Check whether this challenge really need validation. It might already been done in a previous order for the same account.
Sourcepub async fn validate(&self, delay: Duration) -> Result<()>
pub async fn validate(&self, delay: Duration) -> Result<()>
Tell the ACME API to attempt validating the proof of this challenge.
The user must first update the DNS record or HTTP web server depending on the type challenge being validated.
Sourcepub fn api_challenge(&self) -> &ApiChallenge
pub fn api_challenge(&self) -> &ApiChallenge
Access the underlying JSON object for debugging.